# Gabb

A Python wrapper around the services powering the Gabb smartwatch/smartphone. This API is not publically documented, so use at your own risk, as there may be unexpected results of interacting with it directly. The underlying API is the FiLIP service owned by Smartcom (https://smartcom.com/filip-paas/)

## Compatibility

This library was built on, and only ever tested with, Python 3.11 and depends heavily on the [requests](https://pypi.org/project/requests/) library.